require "benchmark"

module MotoRecall::Sampler
  module Util
    def fetch_with_caching_and_logging(key, label, &block)
      result = CACHE.read(key)
      if result.nil?
        result = fetch_with_logging(label, &block)
        CACHE.write(key, result)
      else
        log("Reading #{label} from cache... #{result.length} found", {
          color: :yellow
        })
      end
      result
    end

    def fetch_with_logging(label, &block)
      print "Fetching #{label}... "

      t_0 = Time.now
      results = yield
      t_elapsed = (Time.now - t_0) * 1000

      log_colored_count(results.length, "found (#{t_elapsed}ms)")

      results
    end

    def log_colored_count(count, message)
      log("#{count} #{message}", {
        color: count == 0 ? :red : :green
      })
    end

    def log(message, opts = {})
      puts message.colorize(opts.slice(:color))
    end
  end
end
